'====================================================================
'                    Public constants for:
'                       N U M S . d l l
'              Arbitrary precision numbers library
'                            V 0.01
'                     (C) 2008-2011 DevOTechS
'                 e-mail: support@devotechs.com
'                   --------------------------
' Last modification: 29-August-2011
' 
'====================================================================



'--------------------------------------------------------------------
        'NUMS datatypes
%nu_DT_DecFloat = 1 
%nu_DT_BinFloat = 2 
%nu_DT_BigInt   = 3 
%nu_DT_Rational = 4 
%nu_DT_String   = 5 

%nu_DT_Long     = 6     'These datatypes are not internal datatypes of NUMS
%nu_DT_Dword    = 7 
%nu_DT_Double   = 8 
%nu_DT_Ext      = 9 


        'Constant identifiers
        '     Cached constants (if disk caching is enabled)
%nu_Const_Log2           = 1   'Log(2)       (base e)
%nu_Const_Log10          = 2   'Log(10)      (base e)
%nu_Const_Log256         = 3   'Log(256)     (base e)
%nu_Const_nLog_LogZ      = 4   'Log(1.0625)  (base e) For NUMS internal use. Constant is used by routine n_Log.
%nu_Const_1Log2          = 5   '1/Log(2)     (base e)
%nu_Const_1Log10         = 6   '1/Log(10)    (base e)
%nu_Const_sqrt2          = 7   'sqrt(2)
%nu_Const_Pi             = 8   'Pi
%nu_Const_2Pi            = 9   '2*Pi
%nu_Const_Pi2            = 10  'Pi/2
%nu_Const_Cached         = 10  '<<<< For NUMS internal use. Must equal the number of cached constants !!!

        '     Non-cached constants
%nu_Const_0              = 11  '0
%nu_Const_0_25           = 12  '0.25
%nu_Const_0_5            = 13  '0.5
%nu_Const_1              = 14  '1
%nu_Const_M1             = 15  '-1
%nu_Const_2              = 16  '2
%nu_Const_3              = 17  '3
%nu_Const_5              = 18  '5
%nu_Const_8              = 19  '8
%nu_Const_10             = 20  '10
%nu_Const_16             = 21  '16
%nu_Const_20             = 22  '20
%nu_Const_100            = 23  '100
%nu_Const_125            = 24  '125
%nu_Const_180            = 25  '180
%nu_Const_200            = 26  '200
%nu_Const_256            = 27  '256
%nu_Const_nLog_Z         = 28  '1.0625        For NUMS internal use. Constant is used by routine n_Log.
%nu_Const_nLog_ZT        = 29  '0.96875       For NUMS internal use. Constant is used by routine n_Log.
%nu_Const_ATan_Threshold = 30  '              For NUMS internal use. Constant is used by routine n_ATan
%nu_Const_P_Infinite     = 31  ' "*+inf"   'Plus infinity 
%nu_Const_M_Infinite     = 32  ' "*-inf"   'Minus infinity
%nu_Const_NaN            = 33  ' "*NaN"    'Not a Number  

%nu_Const_HighestID      = 33  '<<<< For NUMS internal use. Must equal the highest constant ID !!!
                              
                              
        'Variables signs      
%nu_Sign_Positive        = +1  
%nu_Sign_Negative        = -1

        'Special values
$nu_Val_P_Infinite       = "*+inf"   'Plus infinity  
$nu_Val_M_Infinite       = "*-inf"   'Minus infinity 
$nu_Val_NaN              = "*NaN"    'Not a Number



        'Modes to set and get precision
%nu_SetPrec_Digits       = 1
%nu_SetPrec_Bits         = 2
%nu_SetPrec_Bytes        = 3

%nu_GetPrec_Digits       = 1
%nu_GetPrec_Bits         = 2  

        'Formats for Var to String conversion
%nu_Format_Normal        = 1
%nu_Format_Scient_Norm   = 2
%nu_Format_Scient_NDP    = 4
%nu_Base_Decimal         = 8
%nu_Base_Hex             = 16
%nu_Base_Binary          = 32


        'Function return values and error values
        'Corresponds with the bitnumbers in 'gNu_GlobalError'
%nu_ErrBit_IllegalInput       =      &h1  '1     1
%nu_ErrBit_IllegalDataType    =      &h2  '2     2
%nu_ErrBit_UnknownDatatype    =      &h4  '3     4
%nu_ErrBit_SpecialValue       =      &h8  '4     8
%nu_ErrBit_AllocUnAllocError  =     &h10  '5     16
%nu_ErrBit_Overflow           =     &h20  '6     32
%nu_ErrBit_FileError          =     &h40  '7     64
%nu_ErrBit_BitManipulation    =     &h80  '8     128
%nu_ErrBit_UnexpectedError    =    &h100  '9     256
%nu_ErrBit_NoResult           =    &h200  '10    512
'                             =    &h400  '11    1024
'                             =    &h800  '12
'                             =   &h1000  '13
'                             =   &h2000  '14
'                             =   &h4000  '15
'                             =   &h8000  '16
'                             =  &h10000  '17
'                             =  &h20000  '18
'                             =  &h40000  '19
'                             =  &h80000  '20
'                             = &h100000  '21
'                             = &h200000  '22
'                             = &h400000  '23
'                             = &h800000  '24



        'Constants for nu_SetOption and nu_GetOption
%nu_Opt_NrPrimes              = 1   'number of primes that are currently stored in NUMSs prime number table
%nu_Opt_NrVariables           = 2   'the number of NUMS variables
%nu_Opt_Kara_Thresh_mul       = 3   'the Karatsuba threshold value for nu_mul (multiplication).
%nu_Opt_Kara_Thresh_sq        = 4   'the Karatsuba threshold value for nu_square (squaring).
%nu_Opt_Pow10_Precision       = 5   'the precision of NUMS's internal power-of-10 table
%nu_Opt_Rat_AutoReduce        = 6   'Set whether rationals should be automatically reduced to their canonical form or not
%nu_Opt_StringFormat          = 7   'Set whether rationals should be automatically reduced to their canonical form or not
%nu_Opt_StringDigits          = 8   'Set whether rationals should be automatically reduced to their canonical form or not
%nu_Opt_DiskCache             = 9   'Set path for (and enable) disk caching.
%nu_Opt_MaxAllocatedVariables = 10  'Get the maximum number of NUMS variables that was allocated during a session


        'Constants for unit conversion
%nu_Convert_Radians2Degrees   = 1
%nu_Convert_Degrees2Radians   = 2
%nu_Convert_Radians2Grads     = 3
%nu_Convert_Grads2Radians     = 4

'--------------------------------------------------------------------
